import type HasActionData from "../Interfaces/HasActionData";
import type HasConditionData from "../Interfaces/HasConditionData";
import type Form from "../Form";
/**
 * Field class.
 *
 * @since 1.0.0
 */
export default class Trigger {
    readonly form: Form;
    readonly name: string;
    readonly type: "change" | "submit";
    readonly conditions: HasConditionData[];
    readonly actions: HasActionData[];
    /**
     * Constructor.
     *
     * @param name Internal name for action.
     * @param trigger Trigger when action fires (change or submit).
     * @param conditions Conditions which have to be fullfilled to run actions after it was triggered.
     * @param actions Actions to be executed.
     *
     * @since 1.0.0
     */
    constructor(form: Form, name: string, type: "change" | "submit", conditions: HasConditionData[], actions: HasActionData[]);
    /**
     * Get trigger type.
     *
     * @returns Type of trigger.
     *
     * @since 1.0.0
     */
    getType(): "change" | "submit";
    run(): void;
}
